@@ -3,6 +3,8 @@
 import base64
 from pathlib import Path
 from functools import partial
+import sphinx
+
 
 from docutils import nodes
 from docutils.parsers.rst import directives
@@ -250,8 +252,10 @@ class CodeTabDirective(GroupTabDirective):
         else:
             try:
                 tab_name = LEXER_MAP[self.arguments[0]]
-            except:
-                raise ValueError("Lexer not implemented: {}".format(self.arguments[0]))
+            except KeyError as invalid_lexer_error:
+                raise ValueError(
+                    "Lexer not implemented: {}".format(self.arguments[0])
+                ) from invalid_lexer_error
 
         self.tab_classes.add("code-tab")
 
@@ -313,7 +317,12 @@ def update_context(app, pagename, templatename, context, doctree):
         return
     visitor = _FindTabsDirectiveVisitor(doctree)
     doctree.walk(visitor)
-    if not visitor.found_tabs_directive:
+
+    include_assets_in_all_pages = False
+    if sphinx.version_info >= (4, 1, 0):
+        include_assets_in_all_pages = app.registry.html_assets_policy == "always"
+
+    if not visitor.found_tabs_directive and not include_assets_in_all_pages:
         paths = [Path("_static") / f for f in FILES]
         if "css_files" in context:
             context["css_files"] = context["css_files"][:]
